/* wiring.h
 *
 * This file defines various wiring schemes.
 *
 * Copyright (C) by Michael McLellan (mikey@cs.auckland.ac.nz)
 * Released under the terms of the GNU GPL, see file COPYING for more details.
 */

/* These defines are for the only availble pins on a parallel port
 * which we can use for output besides pins 2 throuh 9 which are used
 * for data. The address for the below pins is IO + 2 eg. 0x378 + 0x02.
 * Some pins on the parallel port are logicaly reversed which is why
 * some which are ON are 0x00.
 */
#define PIN_1_ON		0x00
#define PIN_1_OFF		0x01
#define PIN_14_ON		0x00
#define PIN_14_OFF		0x02
#define PIN_16_ON		0x04
#define PIN_16_OFF		0x00
#define PIN_17_ON		0x00
#define PIN_17_OFF		0x08

#ifdef WIRING_LCDMOD
/* My own wiring.
 *
 * parallel 14		RS (LCD 4)
 * grounded			RW (LCD 5)
 * parallel 1		EN (LCD 6)
 */
#define RW_WRITE		0x00	// Not needing in my wiring.
#define E1_ON			PIN_1_ON
#define E1_OFF			PIN_1_OFF
#define RS_DATA			PIN_14_ON
#define RS_INST			PIN_14_OFF
#define NUM_CONTROLLERS	1
#endif

#ifdef WIRING_LCDPROC_8_BIT
/* http://lcdproc.omnipotent.net/
 * wiring from lcdtime aswell?
 *
 * parallel 1		RS (LCD 4)
 * parallel 14		RW (LCD 5)
 * parallel 16		EN (LCD 6)
 */
#define RW_WRITE		PIN_14_OFF
#define RS_DATA			PIN_1_ON
#define RS_INST			PIN_1_OFF
#define E1_ON            PIN_16_ON
#define E1_OFF           PIN_16_OFF
#define NUM_CONTROLLERS	1
#endif

#ifdef WIRING_RANDY_RASA
/* http://www.geocities.com/ResearchTriangle/1495/ee_lcd.html
 * http://www.eio.com/lcd2014.htm
 * http://www.rendo.dekooi.nl/~fjbgp/smartie/
 *
 * parallel 16		RS (LCD 4)
 * parallel 14		RW (LCD 5)
 * parallel 1		EN (LCD 6)
 */
#define RW_WRITE		PIN_14_OFF
#define RS_DATA			PIN_16_ON
#define RS_INST			PIN_16_OFF
#define E1_ON			PIN_1_ON
#define E1_OFF			PIN_1_OFF
#define NUM_CONTROLLERS	1
#endif

#ifdef WIRING_LANPOINT
/* This is a 4x40 display which is intergrated with a portable
 * computer called a LANpoint (http://www.lanpoint.com/lanpointpro.asp)
 * This wiring and various other details related to the
 * LANpoint supplied by HA Quoc-Viet, viet@mandrakesoft.com
 *
 * http://qvha.free.fr/lanpoint/lcd.html
 *
 * parallel 16		RS (LCD 9)
 * parallel 17		RW (LCD 10)
 * parallel 1		E1 (LCD 11)
 * parallel 14		E2 (LCD 15)
 */
#define RS_DATA			PIN_17_OFF	// This pin goes through an inverter gate
#define RS_INST			PIN_17_ON	// on the board
#define RW_READ			0x00		// Autofeed pin is dangling
#define RW_WRITE		0x00		// and lcd pin 10 is grounded
#if 0
#define E1_HIGH			PIN_1_ON	// The STROBE pins on the first controller
#define E1_LOW			PIN_1_OFF	// and on the second are logically linked
#define E2_HIGH			PIN_1_ON	// together, ie. they have the same state at
#define E2_LOW			PIN_1_OFF	// the same time.
#define DISPLAY1		PIN_16_OFF	// 16 (INIT) is     ORed with 1 (STROBE)
#define DISPLAY2		PIN_16_ON	// 16 (INIT) is NOT-ORed with 1 (STROBE)
#else
#define E1_ON			PIN_1_ON | PIN_16_OFF
#define E1_OFF			PIN_1_OFF | PIN_16_ON
#define E2_ON			PIN_1_ON | PIN_16_ON
#define E2_OFF			PIN_1_OFF | PIN_16_OFF
#define NUM_CONTROLLERS	2
#define LOW_VOLTAGE
#endif
#endif // WIRING_LANPOINT

#ifndef E2_ON
#define E2_ON			E1_ON
#define E2_OFF			E1_OFF
#endif
